@@ -1,5 +1,3 @@
-import json
-import simplejson
 import aiohttp
 import asyncio
 
@@ -16,13 +14,15 @@ from .models import (
 )
 
 from ..models import JsonModel
-from ..client import Client, FMT, RawClient
+from ..client import Client, RawClient
 from ..errors import (
     APIConfigurationError,
-    ResponseError,
+    RequestError,
     MalformedDataError
 )
 
+from ..processing import Processing
+
 
 class AsyncClient(Client):
     """
@@ -55,7 +55,6 @@ class AsyncClient(Client):
         path,
         method='GET',
         headers: dict = None,
-        return_text=False,
         **kwargs
     ) -> Union[dict, list, str]:
         """Base method for making requests to the api"""
@@ -75,21 +74,11 @@ class AsyncClient(Client):
                     **self.global_request_kwargs
                 )
             except asyncio.exceptions.TimeoutError:
-                raise ResponseError(f'Homeassistant did not respond in time (timeout: {kwargs.get("timeout", 300)} sec)')
-        return await self.response_logic(resp, return_text)
+                raise RequestError(f'Homeassistant did not respond in time (timeout: {kwargs.get("timeout", 300)} sec)')
+        return await self.response_logic(resp)
 
-    async def response_logic(self, response: aiohttp.ClientResponse, return_text=False) -> Union[dict, list, str]:
-        """Processes reponses from the api and formats them"""
-        if content_type := response.headers.get('content-type'):
-            if content_type != self._headers.get('content-type'):
-                raise MalformedDataError(f'Homeassistant responded with non-json response: {await response.text()!r}')
-        try:
-            return await response.json()
-        except (
-            json.decoder.JSONDecodeError,
-            simplejson.decoder.JSONDecodeError
-        ):
-            raise MalformedDataError(f'Homeassistant responded with non-json response: {await response.text()!r}')
+    async def response_logic(self, response):
+        return await Processing(response).process(_async=True)
 
     # Response processing methods
     def process_services_json(self, json: dict) -> AsyncDomain:
@@ -121,21 +110,8 @@ class AsyncClient(Client):
         filter_entity: AsyncEntity = None,
         timestamp: Union[str, datetime] = None,  # Defaults to 1 day before
         end_timestamp: Union[str, datetime] = None
-    ) -> List[dict]:
-        params = {}
-        if filter_entity is not None:
-            params.update(entity=filter_entity.entity_id)
-        if end_timestamp is not None:
-            if isinstance(end_timestamp, datetime):
-                end_timestamp = end_timestamp.strftime(FMT)
-            params.update(end_time=end_timestamp)
-        if timestamp is not None:
-            if isinstance(timestamp, datetime):
-                timestamp = timestamp.strftime(FMT)
-            url = path('logbook', timestamp)
-        else:
-            url = 'logbook'
-        return await self.request(url, params=params)
+    ) -> dict:
+        return await super().logbook_entries(filter_entity, timestamp, end_timestamp)
 
     async def get_history(
         self,
@@ -144,24 +120,14 @@ class AsyncClient(Client):
         end_timestamp: datetime = None,
         minimal_state_data=False,
         significant_changes_only=False
-    ) -> Tuple[Tuple[dict]]:
-        params = {}
-        if entities is not None:
-            params.update(filter_entity_id=','.join([ent.entity_id for ent in entities]))
-        if end_timestamp:
-            end_timestamp = end_timestamp.strftime(FMT)
-            params.update(end_time=end_timestamp)
-        if minimal_state_data:
-            params.update(minimal_response=None)
-        if significant_changes_only:
-            params.update(significant_changes_only=None)
-        if timestamp is not None:
-            if isinstance(timestamp, datetime):
-                timestamp = timestamp.strftime(FMT)
-            url = path('history/period', timestamp)
-        else:
-            url = 'history/period'
-        return await self.request(url, params=self.construct_params(params))
+    ) -> Union[dict, list, str]:
+        return await super().get_history(
+            entities,
+            timestamp,
+            end_timestamp,
+            minimal_state_data,
+            significant_changes_only
+        )
 
     async def get_rendered_template(self, template: str):
         return await self.request('template', json=dict(template=template), return_text=True, method='POST')
@@ -185,7 +151,7 @@ class AsyncClient(Client):
         if res.get('message', None) == 'API running.':
             return True
         else:
-            raise ResponseError('Server response did not return message attribute')
+            raise MalformedDataError('Server response did not return message attribute')
 
     async def malformed_id(self, entity_id: str) -> bool:
         """Checks whether or not a given entity_id is formatted correctly"""
@@ -225,12 +191,13 @@ class AsyncClient(Client):
             state = await self.get_state(entity_id=entity_id)
         else:
             raise ValueError('Neither group and slug or entity_id provided. {help_msg}'.format(
-                help_msg='Use keyword arguments to pass entity_id. Or you can pass the entity_group and entity_slug instead'
+                help_msg='Use keyword arguments to pass entity_id. Or you can pass the entity_group and entity_slug '
+                         'instead '
             ))
         group_id, entity_slug = state.entity_id.split('.')
         group = AsyncGroup(group_id, self)
-        await group.add_entity(entity_slug, state)
-        return await group.get_entity(entity_slug)
+        group.add_entity(entity_slug, state)
+        return group.get_entity(entity_slug)
 
     # Services and domain methods
     async def get_domains(self) -> JsonModel:
